<?php
// $Id: page.tpl.php,v 1.3.2.3 2010/12/31 15:06:46 jarek Exp $

/**
 * @file page.tpl.php
 *
 * Theme implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $css: An array of CSS files for the current page.
 * - $directory: The directory the theme is located in, e.g. themes/garland or
 *   themes/garland/minelli.
 * - $is_front: TRUE if the current page is the front page. Used to toggle the mission statement.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Page metadata:
 * - $language: (object) The language the site is being displayed in.
 *   $language->language contains its textual representation.
 *   $language->dir contains the language direction. It will either be 'ltr' or 'rtl'.
 * - $head_title: A modified version of the page title, for use in the TITLE tag.
 * - $head: Markup for the HEAD section (including meta tags, keyword tags, and
 *   so on).
 * - $styles: Style tags necessary to import all CSS files for the page.
 * - $scripts: Script tags necessary to load the JavaScript files and settings
 *   for the page.
 * - $body_classes: A set of CSS classes for the BODY tag. This contains flags
 *   indicating the current layout (multiple columns, single column), the current
 *   path, whether the user is logged in, and so on.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $mission: The text of the site mission, empty when display has been disabled
 *   in theme settings.
 *
 * headermenu:
 * - $search_box: HTML to display the search box, empty if search has been disabled.
 * - $primary_links (array): An array containing primary headermenu links for the
 *   site, if they have been configured.
 * - $secondary_links (array): An array containing secondary headermenu links for
 *   the site, if they have been configured.
 *
 * Page content (in order of occurrance in the default page.tpl.php):
 * - $left: The HTML for the left sidebar.
 *
 * - $breadcrumb: The breadcrumb trail for the current page.
 * - $title: The page title, for use in the actual HTML content.
 * - $help: Dynamic help text, mostly for admin pages.
 * - $messages: HTML for status and error messages. Should be displayed prominently.
 * - $tabs: Tabs linking to any sub-pages beneath the current page (e.g., the view
 *   and edit tabs when displaying a node).
 *
 * - $content: The main content of the current Drupal page.
 *
 * - $right: The HTML for the right sidebar.
 *
 * Footer/closing data:
 * - $feed_icons: A string of all feed icons for the current page.
 * - $footer_message: The footer message as defined in the admin settings.
 * - $footer : The footer region.
 * - $closure: Final closing markup from any modules that have altered the page.
 *   This variable should always be output last, after all other dynamic content.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 */
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">

<head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <link type="text/css" rel="stylesheet" media="all" href="<?php print $base_path . $directory; ?>/reset.css" />
  <?php print $styles; ?>

  <!--[if lte IE 8]>
  <link type="text/css" rel="stylesheet" href="<?php print $base_path . $directory; ?>/ie8.css" media="all" />
  <![endif]-->

  <!--[if lte IE 7]>
  <link type="text/css" rel="stylesheet" href="<?php print $base_path . $directory; ?>/ie7.css" media="all" />
  <![endif]-->

  <?php
  $color = theme_get_setting('color_scheme');

  $colors = array(
    'blue' => array(
      'base' => '#fffffa',
      'background' => '#467491',
      'link' => '#ce1433',
      'linkhovered' => '#ce1432',
      'text' => '#404040',
      'headermenu' => '#16222b',
      'sidebar' => '#e2eef2',
      'sidebarheader' => '#4a8393',
      'sidebarlink' => '#3f6069',
      'sidebarlinkhovered' => '#131a1c',
      'sidebarborder' => '#cddadf',
      'footer' => '#1a272e',
      'footerheader' => '#6d7e87',
      'footerlink' => '#b2d1e4',
      'footerlinkhovered' => '#fffffe',
      'footerborder' => '#273d4e',
      'closuretext' => '#677881',
      'closurelink' => '#89a2ab',
      'grippie' => '#d1d1d1',
    ),
    'green' => array(
      'base' => '#fffffa',
      'background' => '#7ba00e',
      'link' => '#0a80a1',
      'linkhovered' => '#89a724',
      'text' => '#4a4a4a', 
      'headermenu' => '#272727',
      'sidebar' => '#f4fae3',
      'sidebarheader' => '#393939',
      'sidebarlink' => '#1f89ac',
      'sidebarlinkhovered' => '#89a724',
      'sidebarborder' => '#d6e79f',
      'footer' => '#222222',
      'footerheader' => '#8e938e',
      'footerlink' => '#ced0ce',
      'footerlinkhovered' => '#ffffff',
      'footerborder' => '#525452',
      'closuretext' => '#717671',
      'closurelink' => '#adb0ad',
      'grippie' => '#d1d1d1',
      ),
    'orange' => array(
      'base' => '#fffffa',
      'background' => '#e9860c',
      'link' => '#1d8cc5',
      'linkhovered' => '#45a6d9',
      'text' => '#4a4a4a', 
      'headermenu' => '#272727',
      'sidebar' => '#fef8f3',
      'sidebarheader' => '#393939',
      'sidebarlink' => '#dc2c14',
      'sidebarlinkhovered' => '#e9860c',
      'sidebarborder' => '#fadec6',
      'footer' => '#222222',
      'footerheader' => '#fae7ce',
      'footerlink' => '#f3cb96',
      'footerlinkhovered' => '#ffffff',
      'footerborder' => '#4f4f4f',
      'closuretext' => '#f9ebd8',
      'closurelink' => '#f3cb96',
      'grippie' => '#d1d1d1',
    ),
    'brown' => array(
      'base' => '#fffffa',
      'background' => '#ac895d',
      'link' => '#2a729d',
      'linkhovered' => '#45a6d9',
      'text' => '#4a4a4a', 
      'headermenu' => '#272727',
      'sidebar' => '#fcfaf8',
      'sidebarheader' => '#393939',
      'sidebarlink' => '#866741',
      'sidebarlinkhovered' => '#ce9855',
      'sidebarborder' => '#e7d8cb',
      'footer' => '#222222',
      'footerheader' => '#bc996c',
      'footerlink' => '#d9c7af',
      'footerlinkhovered' => '#ffffff',
      'footerborder' => '#544026',
      'closuretext' => '#ebe4db',
      'closurelink' => '#d4c2aa',
      'grippie' => '#d1d1d1',
    ),
    'gray' => array(
      'base' => '#fffffa',
      'background' => '#969696',
      'link' => '#4b95aa',
      'linkhovered' => '#f2583e',
      'text' => '#4a4a4a', 
      'headermenu' => '#272727',
      'sidebar' => '#f2f5f7',
      'sidebarheader' => '#393939',
      'sidebarlink' => '#4b95aa',
      'sidebarlinkhovered' => '#f2583e',
      'sidebarborder' => '#e0e0e0',
      'footer' => '#3e3c3c',
      'footerheader' => '#d4d4d4',
      'footerlink' => '#c8d7e0',
      'footerlinkhovered' => '#ffffff',
      'footerborder' => '#595959',
      'closuretext' => '#ffffff',
      'closurelink' => '#c8d7e0',
      'grippie' => '#d1d1d1',
    ),
    'aquatic' => array(
      'base' => '#fffffa',
      'background' => '#4eb6c1',
      'link' => '#cb2030',
      'linkhovered' => '#8a1924',
      'text' => '#4a4a4a', 
      'headermenu' => '#1a393d',
      'sidebar' => '#fbfdfe',
      'sidebarheader' => '#393939',
      'sidebarlink' => '#20a29f',
      'sidebarlinkhovered' => '#146765',
      'sidebarborder' => '#d0e6f0',
      'footer' => '#122426',
      'footerheader' => '#8e938e',
      'footerlink' => '#ced0ce',
      'footerlinkhovered' => '#ffffff',
      'footerborder' => '#525452',
      'closuretext' => '#717671',
      'closurelink' => '#adb0ad',
      'grippie' => '#d1d1d1',
    ),
    'pink' => array(
      'base' => '#fffffa',
      'background' => '#bd1f7f',
      'link' => '#1298ab',
      'linkhovered' => '#89a724',
      'text' => '#4a4a4a', 
      'headermenu' => '#292929',
      'sidebar' => '#f0f9d1',
      'sidebarheader' => '#393939',
      'sidebarlink' => '#1298ab',
      'sidebarlinkhovered' => '#89a724',
      'sidebarborder' => '#d6e79f',
      'footer' => '#292929',
      'footerheader' => '#8e938e',
      'footerlink' => '#ced0ce',
      'footerlinkhovered' => '#ffffff',
      'footerborder' => '#525452',
      'closuretext' => '#717671',
      'closurelink' => '#adb0ad',
      'grippie' => '#d1d1d1',
    ),
    'red' => array(
      'base' => '#fffffa',
      'background' => '#c64015',
      'link' => '#1779ab',
      'linkhovered' => '#359ad0',
      'text' => '#4a4a4a', 
      'headermenu' => '#272727',
      'sidebar' => '#fef4f3',
      'sidebarheader' => '#393939',
      'sidebarlink' => '#dc2114',
      'sidebarlinkhovered' => '#ae1d0f',
      'sidebarborder' => '#fadec6',
      'footer' => '#222222',
      'footerheader' => '#f4c3b8',
      'footerlink' => '#ef8a73',
      'footerlinkhovered' => '#ffffff',
      'footerborder' => '#525252',
      'closuretext' => '#f4c3b8',
      'closurelink' => '#ef8a73',
      'grippie' => '#d1d1d1',
    ),
  );
  ?>

  <style type="text/css">
    /* Background (dark blue) */
    body {
      background: <?php print $colors[$color]['background']; ?>;
    }
    .poll .bar .foreground {
      background-color:  <?php print $colors[$color]['background']; ?>;
    }
    #branding a::selection,
    #branding #site-slogan::selection {
    	background-color: #ffffff;
      color:  <?php print $colors[$color]['background']; ?>;
    }
    #branding a::-moz-selection,
    #branding #site-slogan::-moz-selection {
    	background-color: #ffffff;
      color:  <?php print $colors[$color]['background']; ?>;
    }
    /* Sidebar (light blue) */
    #sidebar,
    #sidebar .region  {
      background-color: <?php print $colors[$color]['sidebar']; ?>;
    }
    /* headermenu (very dark blue) */
    #header-menu {
      background-color: <?php print $colors[$color]['headermenu']; ?>;
    }
    /* Footer */
    #footer {
      background-color: <?php print $colors[$color]['footer']; ?>;
    }
    #closure {
      background-color: <?php print $colors[$color]['footer']; ?>;
    }
    /* Footer header */
    #footer .block h2 {
      color: <?php print $colors[$color]['footerheader']; ?>;
    }
    #closure {
      color: <?php print $colors[$color]['footerheader']; ?>;
    }
    #footer {
      color: <?php print $colors[$color]['footerheader']; ?>;
    }
    #footer h1,
    #footer h2,
    #footer h3,
    #footer h4,
    #footer h5,
    #footer h6 {
      color: <?php print $colors[$color]['footerheader']; ?>;;
    }
    /* Footer link */
    #footer .block a {
      color: <?php print $colors[$color]['footerlink']; ?>;
    }
    #footer a:focus {
      outline: 1px dashed <?php print $colors[$color]['footerlink']; ?>;
    }
    #closure a {
      color: <?php print $colors[$color]['footerlink']; ?>;
    }
    /* Footer link hovered */
    #footer a:hover,
    #closure a:hover {
      color: <?php print $colors[$color]['footerlinkhovered']; ?>;
    }
    /* Footer border */
    #footer .block li {
      border-top: 1px solid <?php print $colors[$color]['footerborder']; ?>;
    }
    #footer .block li:first-child {
      border-top: none;
    }
    #closure {
      border-top: 1px solid <?php print $colors[$color]['footerborder']; ?>;
    }
    #footer-column-first,
    #footer-column-second {
      border-left: 1px solid <?php print $colors[$color]['footerborder']; ?>;
    }
    /* Text */
    html {
    	color: <?php print $colors[$color]['text']; ?>;
    }
    .node h1.node-title a::selection,
    .node h2.node-title a::selection,
    a.contextual-links-trigger::selection {
    	background-color: <?php print $colors[$color]['text']; ?>;
      color: #ffffff;
    }
    .node h1.node-title a::-moz-selection,
    .node h2.node-title a::-moz-selection,
    a.contextual-links-trigger::-moz-selection  {
    	background-color: <?php print $colors[$color]['text']; ?>;
      color: #ffffff;
    }
    /* Link */
    a {
      color: <?php print $colors[$color]['link']; ?>;
    }
    a:focus {
      outline: 1px dashed <?php print $colors[$color]['link']; ?>;
    }
    a::selection {
    	background-color: <?php print $colors[$color]['link']; ?>;
      color: #ffffff;
    }
    a::-moz-selection {
    	background-color: <?php print $colors[$color]['link']; ?>;
      color: #ffffff;
    }
    /* Link hovered*/
    a:hover {
      color: <?php print $colors[$color]['linkhovered']; ?>;
    }
    /* Closure text */
    #closure {
      color: <?php print $colors[$color]['closuretext']; ?>;
    }
    #footer a::selection,
    #closure a::selection {
    	background-color: #ffffff;
      color: <?php print $colors[$color]['closuretext']; ?>;
    }
    #footer a::-moz-selection,
    #closure a::-moz-selection {
    	background-color: #ffffff;
      color: <?php print $colors[$color]['closuretext']; ?>;
    }
    /* Closure link */
    #closure a {
      color: <?php print $colors[$color]['closurelink']; ?>;
    } 
    /* Sidebar header */
    #sidebar .block h2 {
      color: <?php print $colors[$color]['sidebarheader']; ?>;
    }
    #sidebar .block h2::selection {
    	background-color: <?php print $colors[$color]['sidebarheader']; ?>;
      color: #ffffff;
    }
    #sidebar .block h2::-moz-selection {
    	background-color: <?php print $colors[$color]['sidebarheader']; ?>;
      color: #ffffff;
    }
    /* Sidebar link */
    #sidebar .block a {
      color: <?php print $colors[$color]['sidebarlink']; ?>;
    }
    #sidebar .block a:active,
    #sidebar .block a:focus {
      outline-color: <?php print $colors[$color]['sidebarlink']; ?>; 
    }
    .node-meta a {
      color: <?php print $colors[$color]['sidebarlink']; ?>;
    }
    .node-meta a:focus,
    .node-meta a:active {
      outline-color: <?php print $colors[$color]['sidebarlink']; ?>;
    }
    #sidebar .block a::selection,
    .node-meta a::selection {
    	background-color: <?php print $colors[$color]['sidebarlink']; ?>;
      color: #ffffff;
    }
    #sidebar .block a::-moz-selection,
    .node-meta a::-moz-selection {
    	background-color: <?php print $colors[$color]['sidebarlink']; ?>;
      color: #ffffff;
    }
    /* Sidebar link hovered */
    #sidebar .block a:hover {
      color: <?php print $colors[$color]['sidebarlinkhovered']; ?>;
    }
    .node-meta a:hover {
      color: <?php print $colors[$color]['sidebarlinkhovered']; ?>;
    }
    /* Sidebar border (blue) */
    #sidebar {
      border-left: 1px solid <?php print $colors[$color]['sidebarborder']; ?>;
    }
    #sidebar .block ul.menu li,
    #sidebar .block div.item-list li {
      border-bottom: 1px solid <?php print $colors[$color]['sidebarborder']; ?>;
    }
    #sidebar .block ul.menu li.first,
    #sidebar .block div.item-list li.first {
      border-top: 1px solid <?php print $colors[$color]['sidebarborder']; ?>;
    }
    /* Grippie */
    .resizable-textarea .grippie {
      background-color: <?php print $colors[$color]['grippie']; ?>;
      border: 1px solid <?php print $colors[$color]['grippie']; ?>;
    }
  </style>

  <?php print $scripts; ?>
</head>
<body class="<?php print $body_classes; ?> <?php print $layout_classes; ?>">

  <div id="wrapper">

    <div id="skip-link">
        <a href="#main-content">Skip to main content</a>
    </div>

    <div id="header">

      <div id="branding">
        <?php if (!empty($logo)): ?>
          <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="logo">
            <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
          </a>
        <?php endif; ?>

        <?php if (!empty($site_name)): ?>
          <div id="site-name">
            <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home"><?php print $site_name; ?></a>
          </div>
        <?php else: /* Use h1 when the content title is empty */ ?>
          <h1 id="site-name">
            <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home"><?php print $site_name; ?></a>
          </h1>
        <?php endif; ?>

        <?php if (!empty($site_slogan)): ?>
          <div id="site-slogan"><?php print $site_slogan; ?></div>
        <?php endif; ?>
      </div> <!-- /#branding -->

      <?php if (!empty($header_menu)): ?>
        <div id="header-menu">
          <?php print $header_menu; ?>
        </div>
      <?php endif; ?>

    </div> <!-- /#header -->

    <div id="main">

      <div id="content">
        <div class="inner">
          <?php if (!empty($breadcrumb)): ?><div id="breadcrumb"><?php print $breadcrumb; ?></div><?php endif; ?>
          <?php if (!empty($messages)): print $messages; endif; ?>
          <?php if (!empty($tabs)): ?><div class="tabs"><?php print $tabs; ?></div><?php endif; ?>

          <a id="main-content"></a>

          <?php if (!empty($title) && !isset($node)): ?>
            <h1 class="page-title"><?php print $title ?></h1>
          <?php endif; ?>

          <?php if (!empty($help)): print $help; endif; ?>
            <div class="region region-content">
              <?php print $content; ?>
            </div>
          <?php print $feed_icons; ?>
        </div> <!-- /.inner -->
      </div> <!-- /#content -->

        <?php if (!empty($sidebar)): ?>
            <div id="sidebar">
              <div class="region region-sidebar">
                <?php print $sidebar; ?>
              </div>
            </div> <!-- /#sidebar -->
        <?php endif; ?>


    </div> <!-- /#main -->

  <div id="footer-wrapper">
    <div id="footer">

      <?php if (!empty($footer_column_first) || !empty($footer_column_second) || !empty($footer_column_third) || !empty($footer_column_fourth)): ?>
        <h2 class="element-invisible"><?php print t('Footer'); ?></h2>
        <div id="footer-columns" class="columns-4">
          <?php if (!empty($footer_column_first)): ?>
            <div id="footer-column-first" class="column first">
              <div class="region">
                <?php print $footer_column_first; ?>
              </div>
            </div> <!-- /#footer-column-first -->
          <?php endif; ?>

          <?php if (!empty($footer_column_second)): ?>
            <div id="footer-column-second" class="column <?php if (empty($footer_column_first)): ?> first<?php endif; ?><?php if (empty($footer_column_third) && empty($footer_column_fourth)): ?> last<?php endif; ?>">
              <div class="region">
                <?php print $footer_column_second; ?>
              </div>
            </div> <!-- /#footer-column-second -->
          <?php endif; ?>

          <?php if (!empty($footer_column_third)): ?>
            <div id="footer-column-third" class="column <?php if (empty($footer_column_first) && empty($footer_column_second)): ?> first<?php endif; ?><?php if (empty($footer_column_fourth)): ?> last<?php endif; ?>">
              <div class="region">
                <?php print $footer_column_third; ?>
              </div>
            </div> <!-- /#footer-column-third -->
          <?php endif; ?>

          <?php if (!empty($footer_column_fourth)): ?>
            <div id="footer-column-fourth" class="column last <?php if (empty($footer_column_first) && empty($footer_column_second) && empty($footer_column_third)): ?> first<?php endif; ?>">
              <div class="region">
                <?php print $footer_column_fourth; ?>
              </div>
            </div> <!-- /#footer-column-fourth -->
          <?php endif; ?>
        </div><!-- /#footer-columns -->
      <?php endif; ?>

      <div id="closure">

        <div id="info">Drupal theme by <a href="http://www.woothemes.com">WooThemes</a> and <a href="http://www.kiwi-themes.com">Kiwi Themes</a></div>

        <?php if ($footer_menu): ?>
          <div id="footer-menu">
            <?php print $footer_menu; ?>
          </div>
        <?php endif; ?>

      </div> <!-- /#closure -->

      </div> <!-- /#footer -->
    </div> <!-- /#footer-wrapper -->

  </div> <!-- /#wrapper -->

  <?php print $closure; ?>

</body>
</html>
